[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

xserver-xorg-video-intel: Changes to 'debian-unstable'



 ChangeLog           |  762 ++++++++++++++++++++++++++++++++++++++++++++++++++++
 configure           |   59 ++--
 configure.ac        |    6 
 debian/changelog    |    6 
 depcomp             |   33 +-
 install-sh          |  228 ++++++++-------
 ltmain.sh           |   58 ++-
 man/intel.man       |    7 
 src/brw_structs.h   |   12 
 src/ch7017/ch7017.c |    2 
 src/ch7xxx/ch7xxx.c |    2 
 src/common.h        |   20 +
 src/i810_driver.c   |    6 
 src/i810_reg.h      |    5 
 src/i830.h          |    2 
 src/i830_crt.c      |    1 
 src/i830_debug.c    |   84 +++--
 src/i830_display.c  |  102 ++++--
 src/i830_driver.c   |   67 +++-
 src/i830_dvo.c      |    2 
 src/i830_lvds.c     |   19 +
 src/i830_memory.c   |   25 +
 src/i830_quirks.c   |   14 
 src/i830_sdvo.c     |   18 -
 src/i830_video.c    |   12 
 src/i965_render.c   |    6 
 src/i965_video.c    |    5 
 src/ivch/ivch.c     |    2 
 src/sil164/sil164.c |    2 
 src/tfp410/tfp410.c |    2 
 30 files changed, 1286 insertions(+), 283 deletions(-)

New commits:
commit 54ddbe79b07d9441575bc33972431003350b6c59
Author: Julien Cristau <jcristau@debian.org>
Date:   Wed Feb 6 10:27:25 2008 +0100

    Prepare changelog for upload.

diff --git a/debian/changelog b/debian/changelog
index 2cf8698..39ed355 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,8 +1,8 @@
-xserver-xorg-video-intel (2:2.2.0.90-2) UNRELEASED; urgency=low
+xserver-xorg-video-intel (2:2.2.0.90-2) unstable; urgency=low
 
   * Actually pull the new upstream release candidate.
 
- -- Julien Cristau <jcristau@debian.org>  Wed, 06 Feb 2008 10:22:40 +0100
+ -- Julien Cristau <jcristau@debian.org>  Wed, 06 Feb 2008 10:27:18 +0100
 
 xserver-xorg-video-intel (2:2.2.0.90-1) unstable; urgency=low
 

commit 426e5c98d08cf5cac64180828a20a57d2299bd45
Author: Julien Cristau <jcristau@debian.org>
Date:   Wed Feb 6 10:26:54 2008 +0100

    autoreconf

diff --git a/configure b/configure
index 1b81f23..aabba24 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.61 for xf86-video-intel 2.2.0.
+# Generated by GNU Autoconf 2.61 for xf86-video-intel 2.2.0.90.
 #
 # Report bugs to <https://bugs.freedesktop.org/enter_bug.cgi?product=xorg>.
 #
@@ -728,8 +728,8 @@ SHELL=${CONFIG_SHELL-/bin/sh}
 # Identity of this package.
 PACKAGE_NAME='xf86-video-intel'
 PACKAGE_TARNAME='xf86-video-intel'
-PACKAGE_VERSION='2.2.0'
-PACKAGE_STRING='xf86-video-intel 2.2.0'
+PACKAGE_VERSION='2.2.0.90'
+PACKAGE_STRING='xf86-video-intel 2.2.0.90'
 PACKAGE_BUGREPORT='https://bugs.freedesktop.org/enter_bug.cgi?product=xorg'
 
 ac_unique_file="Makefile.am"
@@ -1453,7 +1453,7 @@ if test "$ac_init_help" = "long"; then
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures xf86-video-intel 2.2.0 to adapt to many kinds of systems.
+\`configure' configures xf86-video-intel 2.2.0.90 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1523,7 +1523,7 @@ fi
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of xf86-video-intel 2.2.0:";;
+     short | recursive ) echo "Configuration of xf86-video-intel 2.2.0.90:";;
    esac
   cat <<\_ACEOF
 
@@ -1648,7 +1648,7 @@ fi
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-xf86-video-intel configure 2.2.0
+xf86-video-intel configure 2.2.0.90
 generated by GNU Autoconf 2.61
 
 Copyright (C) 1992, 1993, 1994, 1995, 1996, 1998, 1999, 2000, 2001,
@@ -1662,7 +1662,7 @@ cat >config.log <<_ACEOF
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by xf86-video-intel $as_me 2.2.0, which was
+It was created by xf86-video-intel $as_me 2.2.0.90, which was
 generated by GNU Autoconf 2.61.  Invocation command line was
 
   $ $0 $@
@@ -2357,7 +2357,7 @@ fi
 
 # Define the identity of the package.
  PACKAGE='xf86-video-intel'
- VERSION='2.2.0'
+ VERSION='2.2.0.90'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -21919,12 +21919,12 @@ if test -n "$PKG_CONFIG"; then
         pkg_cv_PCIACCESS_CFLAGS="$PCIACCESS_CFLAGS"
     else
         if test -n "$PKG_CONFIG" && \
-    { (echo "$as_me:$LINENO: \$PKG_CONFIG --exists --print-errors \"pciaccess >= 0.5.0\"") >&5
-  ($PKG_CONFIG --exists --print-errors "pciaccess >= 0.5.0") 2>&5
+    { (echo "$as_me:$LINENO: \$PKG_CONFIG --exists --print-errors \"pciaccess >= 0.10.0\"") >&5
+  ($PKG_CONFIG --exists --print-errors "pciaccess >= 0.10.0") 2>&5
   ac_status=$?
   echo "$as_me:$LINENO: \$? = $ac_status" >&5
   (exit $ac_status); }; then
-  pkg_cv_PCIACCESS_CFLAGS=`$PKG_CONFIG --cflags "pciaccess >= 0.5.0" 2>/dev/null`
+  pkg_cv_PCIACCESS_CFLAGS=`$PKG_CONFIG --cflags "pciaccess >= 0.10.0" 2>/dev/null`
 else
   pkg_failed=yes
 fi
@@ -21937,12 +21937,12 @@ if test -n "$PKG_CONFIG"; then
         pkg_cv_PCIACCESS_LIBS="$PCIACCESS_LIBS"
     else
         if test -n "$PKG_CONFIG" && \
-    { (echo "$as_me:$LINENO: \$PKG_CONFIG --exists --print-errors \"pciaccess >= 0.5.0\"") >&5
-  ($PKG_CONFIG --exists --print-errors "pciaccess >= 0.5.0") 2>&5
+    { (echo "$as_me:$LINENO: \$PKG_CONFIG --exists --print-errors \"pciaccess >= 0.10.0\"") >&5
+  ($PKG_CONFIG --exists --print-errors "pciaccess >= 0.10.0") 2>&5
   ac_status=$?
   echo "$as_me:$LINENO: \$? = $ac_status" >&5
   (exit $ac_status); }; then
-  pkg_cv_PCIACCESS_LIBS=`$PKG_CONFIG --libs "pciaccess >= 0.5.0" 2>/dev/null`
+  pkg_cv_PCIACCESS_LIBS=`$PKG_CONFIG --libs "pciaccess >= 0.10.0" 2>/dev/null`
 else
   pkg_failed=yes
 fi
@@ -21961,9 +21961,9 @@ else
         _pkg_short_errors_supported=no
 fi
         if test $_pkg_short_errors_supported = yes; then
-	        PCIACCESS_PKG_ERRORS=`$PKG_CONFIG --short-errors --errors-to-stdout --print-errors "pciaccess >= 0.5.0"`
+	        PCIACCESS_PKG_ERRORS=`$PKG_CONFIG --short-errors --errors-to-stdout --print-errors "pciaccess >= 0.10.0"`
         else
-	        PCIACCESS_PKG_ERRORS=`$PKG_CONFIG --errors-to-stdout --print-errors "pciaccess >= 0.5.0"`
+	        PCIACCESS_PKG_ERRORS=`$PKG_CONFIG --errors-to-stdout --print-errors "pciaccess >= 0.10.0"`
         fi
 	# Put the nasty error message in config.log where it belongs
 	echo "$PCIACCESS_PKG_ERRORS" >&5
@@ -22377,6 +22377,29 @@ DRIVER_NAME=intel
 
 
 
+	XORG_MACROS_needed_version=1.1.3
+	XORG_MACROS_needed_major=`echo $XORG_MACROS_needed_version | sed 's/\..*$//'`
+	XORG_MACROS_needed_minor=`echo $XORG_MACROS_needed_version | sed -e 's/^[0-9]*\.//' -e 's/\..*$//'`
+	{ echo "$as_me:$LINENO: checking if xorg-macros used to generate configure is at least ${XORG_MACROS_needed_major}.${XORG_MACROS_needed_minor}" >&5
+echo $ECHO_N "checking if xorg-macros used to generate configure is at least ${XORG_MACROS_needed_major}.${XORG_MACROS_needed_minor}... $ECHO_C" >&6; }
+	XORG_MACROS_version=1.1.5
+	XORG_MACROS_major=`echo $XORG_MACROS_version | sed 's/\..*$//'`
+	XORG_MACROS_minor=`echo $XORG_MACROS_version | sed -e 's/^[0-9]*\.//' -e 's/\..*$//'`
+	if test $XORG_MACROS_major -ne $XORG_MACROS_needed_major ; then
+		{ { echo "$as_me:$LINENO: error: configure built with incompatible version of xorg-macros.m4 - requires version ${XORG_MACROS_major}.x" >&5
+echo "$as_me: error: configure built with incompatible version of xorg-macros.m4 - requires version ${XORG_MACROS_major}.x" >&2;}
+   { (exit 1); exit 1; }; }
+	fi
+	if test $XORG_MACROS_minor -lt $XORG_MACROS_needed_minor ; then
+		{ { echo "$as_me:$LINENO: error: configure built with too old of a version of xorg-macros.m4 - requires version ${XORG_MACROS_major}.${XORG_MACROS_minor}.0 or newer" >&5
+echo "$as_me: error: configure built with too old of a version of xorg-macros.m4 - requires version ${XORG_MACROS_major}.${XORG_MACROS_minor}.0 or newer" >&2;}
+   { (exit 1); exit 1; }; }
+	fi
+	{ echo "$as_me:$LINENO: result: yes, $XORG_MACROS_version" >&5
+echo "${ECHO_T}yes, $XORG_MACROS_version" >&6; }
+
+
+
 
 if test x$APP_MAN_SUFFIX = x    ; then
     APP_MAN_SUFFIX=1
@@ -23137,7 +23160,7 @@ exec 6>&1
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by xf86-video-intel $as_me 2.2.0, which was
+This file was extended by xf86-video-intel $as_me 2.2.0.90, which was
 generated by GNU Autoconf 2.61.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -23190,7 +23213,7 @@ Report bugs to <bug-autoconf@gnu.org>."
 _ACEOF
 cat >>$CONFIG_STATUS <<_ACEOF
 ac_cs_version="\\
-xf86-video-intel config.status 2.2.0
+xf86-video-intel config.status 2.2.0.90
 configured by $0, generated by GNU Autoconf 2.61,
   with options \\"`echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`\\"
 
diff --git a/depcomp b/depcomp
index ca5ea4e..e5f9736 100755
--- a/depcomp
+++ b/depcomp
@@ -1,9 +1,9 @@
 #! /bin/sh
 # depcomp - compile a program generating dependencies as side-effects
 
-scriptversion=2006-10-15.18
+scriptversion=2007-03-29.01
 
-# Copyright (C) 1999, 2000, 2003, 2004, 2005, 2006 Free Software
+# Copyright (C) 1999, 2000, 2003, 2004, 2005, 2006, 2007 Free Software
 # Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
@@ -215,34 +215,39 @@ aix)
   # current directory.  Also, the AIX compiler puts `$object:' at the
   # start of each line; $object doesn't have directory information.
   # Version 6 uses the directory in both cases.
-  stripped=`echo "$object" | sed 's/\(.*\)\..*$/\1/'`
-  tmpdepfile="$stripped.u"
+  dir=`echo "$object" | sed -e 's|/[^/]*$|/|'`
+  test "x$dir" = "x$object" && dir=
+  base=`echo "$object" | sed -e 's|^.*/||' -e 's/\.o$//' -e 's/\.lo$//'`
   if test "$libtool" = yes; then
+    tmpdepfile1=$dir$base.u
+    tmpdepfile2=$base.u
+    tmpdepfile3=$dir.libs/$base.u
     "$@" -Wc,-M
   else
+    tmpdepfile1=$dir$base.u
+    tmpdepfile2=$dir$base.u
+    tmpdepfile3=$dir$base.u
     "$@" -M
   fi
   stat=$?
 
-  if test -f "$tmpdepfile"; then :
-  else
-    stripped=`echo "$stripped" | sed 's,^.*/,,'`
-    tmpdepfile="$stripped.u"
-  fi
-
   if test $stat -eq 0; then :
   else
-    rm -f "$tmpdepfile"
+    rm -f "$tmpdepfile1" "$tmpdepfile2" "$tmpdepfile3"
     exit $stat
   fi
 
+  for tmpdepfile in "$tmpdepfile1" "$tmpdepfile2" "$tmpdepfile3"
+  do
+    test -f "$tmpdepfile" && break
+  done
   if test -f "$tmpdepfile"; then
-    outname="$stripped.o"
     # Each line is of the form `foo.o: dependent.h'.
     # Do two passes, one to just change these to
     # `$object: dependent.h' and one to simply `dependent.h:'.
-    sed -e "s,^$outname:,$object :," < "$tmpdepfile" > "$depfile"
-    sed -e "s,^$outname: \(.*\)$,\1:," < "$tmpdepfile" >> "$depfile"
+    sed -e "s,^.*\.[a-z]*:,$object:," < "$tmpdepfile" > "$depfile"
+    # That's a tab and a space in the [].
+    sed -e 's,^.*\.[a-z]*:[	 ]*,,' -e 's,$,:,' < "$tmpdepfile" >> "$depfile"
   else
     # The sourcefile does not contain any dependencies, so just
     # store a dummy comment line, to avoid errors with the Makefile
diff --git a/install-sh b/install-sh
index 4fbbae7..a5897de 100755
--- a/install-sh
+++ b/install-sh
@@ -1,7 +1,7 @@
 #!/bin/sh
 # install - install a program, script, or datafile
 
-scriptversion=2006-10-14.15
+scriptversion=2006-12-25.00
 
 # This originates from X11R5 (mit/util/scripts/install.sh), which was
 # later released in X11R6 (xc/config/util/install.sh) with the
@@ -48,7 +48,7 @@ IFS=" ""	$nl"
 # set DOITPROG to echo to test this script
 
 # Don't use :- since 4.3BSD and earlier shells don't like it.
-doit="${DOITPROG-}"
+doit=${DOITPROG-}
 if test -z "$doit"; then
   doit_exec=exec
 else
@@ -58,34 +58,49 @@ fi
 # Put in absolute file names if you don't have them in your path;
 # or use environment vars.
 
-mvprog="${MVPROG-mv}"
-cpprog="${CPPROG-cp}"
-chmodprog="${CHMODPROG-chmod}"
-chownprog="${CHOWNPROG-chown}"
-chgrpprog="${CHGRPPROG-chgrp}"
-stripprog="${STRIPPROG-strip}"
-rmprog="${RMPROG-rm}"
-mkdirprog="${MKDIRPROG-mkdir}"
+chgrpprog=${CHGRPPROG-chgrp}
+chmodprog=${CHMODPROG-chmod}
+chownprog=${CHOWNPROG-chown}
+cmpprog=${CMPPROG-cmp}
+cpprog=${CPPROG-cp}
+mkdirprog=${MKDIRPROG-mkdir}
+mvprog=${MVPROG-mv}
+rmprog=${RMPROG-rm}
+stripprog=${STRIPPROG-strip}
+
+posix_glob='?'
+initialize_posix_glob='
+  test "$posix_glob" != "?" || {
+    if (set -f) 2>/dev/null; then
+      posix_glob=
+    else
+      posix_glob=:
+    fi
+  }
+'
 
-posix_glob=
 posix_mkdir=
 
 # Desired mode of installed file.
 mode=0755
 
+chgrpcmd=
 chmodcmd=$chmodprog
 chowncmd=
-chgrpcmd=
-stripcmd=
+mvcmd=$mvprog
 rmcmd="$rmprog -f"
-mvcmd="$mvprog"
+stripcmd=
+
 src=
 dst=
 dir_arg=
-dstarg=
+dst_arg=
+
+copy_on_change=false
 no_target_directory=
 
-usage="Usage: $0 [OPTION]... [-T] SRCFILE DSTFILE
+usage="\
+Usage: $0 [OPTION]... [-T] SRCFILE DSTFILE
    or: $0 [OPTION]... SRCFILES... DIRECTORY
    or: $0 [OPTION]... -t DIRECTORY SRCFILES...
    or: $0 [OPTION]... -d DIRECTORIES...
@@ -95,65 +110,55 @@ In the 2nd and 3rd, copy all SRCFILES to DIRECTORY.
 In the 4th, create DIRECTORIES.
 
 Options:
--c         (ignored)
--d         create directories instead of installing files.
--g GROUP   $chgrpprog installed files to GROUP.
--m MODE    $chmodprog installed files to MODE.
--o USER    $chownprog installed files to USER.
--s         $stripprog installed files.
--t DIRECTORY  install into DIRECTORY.
--T         report an error if DSTFILE is a directory.
---help     display this help and exit.
---version  display version info and exit.
+     --help     display this help and exit.
+     --version  display version info and exit.
+
+  -c            (ignored)
+  -C            install only if different (preserve the last data modification time)
+  -d            create directories instead of installing files.
+  -g GROUP      $chgrpprog installed files to GROUP.
+  -m MODE       $chmodprog installed files to MODE.
+  -o USER       $chownprog installed files to USER.
+  -s            $stripprog installed files.
+  -t DIRECTORY  install into DIRECTORY.
+  -T            report an error if DSTFILE is a directory.
 
 Environment variables override the default commands:
-  CHGRPPROG CHMODPROG CHOWNPROG CPPROG MKDIRPROG MVPROG RMPROG STRIPPROG
+  CHGRPPROG CHMODPROG CHOWNPROG CMPPROG CPPROG MKDIRPROG MVPROG
+  RMPROG STRIPPROG
 "
 
 while test $# -ne 0; do
   case $1 in
-    -c) shift
-        continue;;
+    -c) ;;
+
+    -C) copy_on_change=true;;
 
-    -d) dir_arg=true
-        shift
-        continue;;
+    -d) dir_arg=true;;
 
     -g) chgrpcmd="$chgrpprog $2"
-        shift
-        shift
-        continue;;
+	shift;;
 
     --help) echo "$usage"; exit $?;;
 
     -m) mode=$2
-        shift
-        shift
 	case $mode in
 	  *' '* | *'	'* | *'
 '*	  | *'*'* | *'?'* | *'['*)
 	    echo "$0: invalid mode: $mode" >&2
 	    exit 1;;
 	esac
-        continue;;
+	shift;;
 
     -o) chowncmd="$chownprog $2"
-        shift
-        shift
-        continue;;
+	shift;;
 
-    -s) stripcmd=$stripprog
-        shift
-        continue;;
+    -s) stripcmd=$stripprog;;
 
-    -t) dstarg=$2
-	shift
-	shift
-	continue;;
+    -t) dst_arg=$2
+	shift;;
 
-    -T) no_target_directory=true
-	shift
-	continue;;
+    -T) no_target_directory=true;;
 
     --version) echo "$0 $scriptversion"; exit $?;;
 
@@ -165,21 +170,22 @@ while test $# -ne 0; do
 
     *)  break;;
   esac
+  shift
 done
 
-if test $# -ne 0 && test -z "$dir_arg$dstarg"; then
+if test $# -ne 0 && test -z "$dir_arg$dst_arg"; then
   # When -d is used, all remaining arguments are directories to create.
   # When -t is used, the destination is already specified.
   # Otherwise, the last argument is the destination.  Remove it from $@.
   for arg
   do
-    if test -n "$dstarg"; then
+    if test -n "$dst_arg"; then
       # $@ is not empty: it contains at least $arg.
-      set fnord "$@" "$dstarg"
+      set fnord "$@" "$dst_arg"
       shift # fnord
     fi
     shift # arg
-    dstarg=$arg
+    dst_arg=$arg
   done
 fi
 
@@ -224,7 +230,7 @@ for src
 do
   # Protect names starting with `-'.
   case $src in
-    -*) src=./$src ;;
+    -*) src=./$src;;
   esac
 
   if test -n "$dir_arg"; then
@@ -242,22 +248,22 @@ do
       exit 1
     fi
 
-    if test -z "$dstarg"; then
+    if test -z "$dst_arg"; then
       echo "$0: no destination specified." >&2
       exit 1
     fi
 
-    dst=$dstarg
+    dst=$dst_arg
     # Protect names starting with `-'.
     case $dst in
-      -*) dst=./$dst ;;
+      -*) dst=./$dst;;
     esac
 
     # If destination is a directory, append the input filename; won't work
     # if double slashes aren't ignored.
     if test -d "$dst"; then
       if test -n "$no_target_directory"; then
-	echo "$0: $dstarg: Is a directory" >&2
+	echo "$0: $dst_arg: Is a directory" >&2
 	exit 1
       fi
       dstdir=$dst
@@ -378,26 +384,19 @@ do
       # directory the slow way, step by step, checking for races as we go.
 
       case $dstdir in
-	/*) prefix=/ ;;
-	-*) prefix=./ ;;
-	*)  prefix= ;;
+	/*) prefix='/';;
+	-*) prefix='./';;
+	*)  prefix='';;
       esac
 
-      case $posix_glob in
-        '')
-	  if (set -f) 2>/dev/null; then
-	    posix_glob=true
-	  else
-	    posix_glob=false
-	  fi ;;
-      esac
+      eval "$initialize_posix_glob"
 
       oIFS=$IFS
       IFS=/
-      $posix_glob && set -f
+      $posix_glob set -f
       set fnord $dstdir
       shift
-      $posix_glob && set +f
+      $posix_glob set +f
       IFS=$oIFS
 
       prefixes=
@@ -459,41 +458,54 @@ do
     # ignore errors from any of these, just make sure not to ignore
     # errors from the above "$doit $cpprog $src $dsttmp" command.
     #
-    { test -z "$chowncmd" || $doit $chowncmd "$dsttmp"; } \
-      && { test -z "$chgrpcmd" || $doit $chgrpcmd "$dsttmp"; } \
-      && { test -z "$stripcmd" || $doit $stripcmd "$dsttmp"; } \
-      && { test -z "$chmodcmd" || $doit $chmodcmd $mode "$dsttmp"; } &&
-
-    # Now rename the file to the real destination.
-    { $doit $mvcmd -f "$dsttmp" "$dst" 2>/dev/null \
-      || {
-	   # The rename failed, perhaps because mv can't rename something else
-	   # to itself, or perhaps because mv is so ancient that it does not
-	   # support -f.
-
-	   # Now remove or move aside any old file at destination location.
-	   # We try this two ways since rm can't unlink itself on some
-	   # systems and the destination file might be busy for other
-	   # reasons.  In this case, the final cleanup might fail but the new
-	   # file should still install successfully.
-	   {
-	     if test -f "$dst"; then
-	       $doit $rmcmd -f "$dst" 2>/dev/null \
-	       || { $doit $mvcmd -f "$dst" "$rmtmp" 2>/dev/null \
-		     && { $doit $rmcmd -f "$rmtmp" 2>/dev/null; :; }; }\
-	       || {
-		 echo "$0: cannot unlink or rename $dst" >&2
-		 (exit 1); exit 1
-	       }
-	     else
-	       :
-	     fi
-	   } &&
-
-	   # Now rename the file to the real destination.
-	   $doit $mvcmd "$dsttmp" "$dst"
-	 }
-    } || exit 1
+    { test -z "$chowncmd" || $doit $chowncmd "$dsttmp"; } &&
+    { test -z "$chgrpcmd" || $doit $chgrpcmd "$dsttmp"; } &&
+    { test -z "$stripcmd" || $doit $stripcmd "$dsttmp"; } &&
+    { test -z "$chmodcmd" || $doit $chmodcmd $mode "$dsttmp"; } &&
+
+    # If -C, don't bother to copy if it wouldn't change the file.
+    if $copy_on_change &&
+       old=`LC_ALL=C ls -dlL "$dst"	2>/dev/null` &&
+       new=`LC_ALL=C ls -dlL "$dsttmp"	2>/dev/null` &&
+
+       eval "$initialize_posix_glob" &&
+       $posix_glob set -f &&
+       set X $old && old=:$2:$4:$5:$6 &&
+       set X $new && new=:$2:$4:$5:$6 &&
+       $posix_glob set +f &&
+
+       test "$old" = "$new" &&
+       $cmpprog "$dst" "$dsttmp" >/dev/null 2>&1
+    then
+      rm -f "$dsttmp"
+    else
+      # Rename the file to the real destination.
+      $doit $mvcmd -f "$dsttmp" "$dst" 2>/dev/null ||
+
+      # The rename failed, perhaps because mv can't rename something else
+      # to itself, or perhaps because mv is so ancient that it does not
+      # support -f.
+      {
+	# Now remove or move aside any old file at destination location.
+	# We try this two ways since rm can't unlink itself on some
+	# systems and the destination file might be busy for other
+	# reasons.  In this case, the final cleanup might fail but the new
+	# file should still install successfully.
+	{
+	  test ! -f "$dst" ||
+	  $doit $rmcmd -f "$dst" 2>/dev/null ||
+	  { $doit $mvcmd -f "$dst" "$rmtmp" 2>/dev/null &&
+	    { $doit $rmcmd -f "$rmtmp" 2>/dev/null; :; }
+	  } ||
+	  { echo "$0: cannot unlink or rename $dst" >&2
+	    (exit 1); exit 1
+	  }
+	} &&
+
+	# Now rename the file to the real destination.
+	$doit $mvcmd "$dsttmp" "$dst"
+      }
+    fi || exit 1
 
     trap '' 0
   fi
diff --git a/ChangeLog b/ChangeLog
index cafd694..2523b7e 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,765 @@
+commit 0516e708abf01d1f83e2e8af9abe4c835ed79444
+Author: Jesse Barnes <jbarnes@hobbes.virtuousgeek.org>
+Date:   Tue Feb 5 17:39:26 2008 -0800
+
+    Fix version bump, should have been 2.2.0.90
+
+commit 44628efffa6e84e810a26cd201f7312793b5cf63
+Author: Jesse Barnes <jbarnes@hobbes.virtuousgeek.org>
+Date:   Tue Feb 5 17:35:54 2008 -0800
+
+    Bump version to 2.2.1.90 for 2.2.1 pre-release
+
+commit 4398c0a163b348ccca15d705fcad5bc27604919a
+Author: Jesse Barnes <jbarnes@hobbes.virtuousgeek.org>
+Date:   Tue Feb 5 17:09:19 2008 -0800
+
+    Fix build warnings on 64 bit
+    
+    Use PRIx32 for printing CARD32 types, and PRIx64 for portably printing uint64_t
+    types.  Requires the addition of a new include, inttypes.h, to work.  Hope C99
+    is ok with everybody...
+
+commit f4d8a5bb6c6a84d6b90157d2e25564dc68bfb7bf
+Author: Jesse Barnes <jbarnes@hobbes.virtuousgeek.org>
+Date:   Tue Feb 5 17:31:58 2008 -0800
+
+    Fix typo in merge
+    
+    Left a conflict line in...
+
+commit 52557ecc6df12d02b9808895394ca12702373e9b
+Author: Jesse Barnes <jbarnes@hobbes.virtuousgeek.org>
+Date:   Tue Feb 5 17:30:48 2008 -0800
+
+    Only enable FBC if one pipe is active
+    
+    Some chips can't support FBC if multiple pipes are active.  So if more than one
+    pipe is on or we're going from one->two pipes enabled, make sure FBC is
+    disabled.
+    
+    Intended to fix 13418, 13326, 13152.
+    
+    Conflicts:
+    
+    	src/i830_display.c - don't pull in FBC2 code
+
+commit e9cb38e25619aa8eb1b7faac5fa3749e4e993997
+Author: liuhong <liuhong@devlinux-hong.sh.intel.com>
+Date:   Tue Feb 5 11:04:34 2008 +0800
+
+    xf86-video-intel: fix ivch using wrong dvo register
+    
+    We use the wrong DVO output register for ivch which is used for DVO LVDS.
+    Vbios enables DVOB and driver never touches it, so everything seems
+    working correctly now.
+
+commit 02d12583e313898a5f14ff968ac4360bce3eff3d
+Author: Jesse Barnes <jbarnes@hobbes.virtuousgeek.org>
+Date:   Tue Feb 5 11:36:24 2008 -0800
+
+    Program FBC fence offset register
+    
+    Just a partial fix for some of the FBC issues people have been seeing.  The
+    other half is to disable FBC if both pipes are running.
+
+commit 58cb85a7e4c760adc78128bdf605b7885ac32538
+Author: Zhenyu Wang <zhenyu.z.wang@intel.com>
+Date:   Tue Feb 5 10:34:55 2008 +0800
+
+    Fix last commit on i8xx debug p2 value
+
+commit 7e6b43960979829946669314d6523573f79e207d
+Author: Hong Liu <hong.liu@intel.com>
+Date:   Tue Feb 5 09:10:48 2008 +0800
+
+    Fix PLL reference clk debug dump
+
+commit a70b59bd44d14e77c9e522dbe225b62a8bcf3050
+Author: Hong Liu <hong.liu@intel.com>
+Date:   Tue Feb 5 09:06:14 2008 +0800
+
+    Allow non-strict free order for bo_list
+
+commit fa841fd05bdebb991f4e4db201e6a260557e2dad
+Author: Hong Liu <hong.liu@intel.com>
+Date:   Tue Feb 5 08:58:44 2008 +0800
+
+    Bug 10584: Mac Mini EDID data assigned to TMDS output
+    
+    EDID data for TMDS output got from crt should be applied
+    to TMDS output on mac mini.
+
+commit 4e5c7ad8bdee98bd23a7066f57d0942e64a415fd
+Author: Hong Liu <hong.liu@intel.com>
+Date:   Mon Feb 4 17:14:23 2008 +0800
+
+    Bug 10773: fix i8xx pll p2 value in i830_crtc_clock_get()
+    
+    Also fix debug dump, slightly modified to use macro instead.
+
+commit ba619ef92b1b1303d8cf76ebd68dea978d17eb7a
+Author: Paulo Cesar Pereira de Andrade <pcpa@mandriva.com>
+Date:   Thu Jan 31 22:47:18 2008 -0200
+
+    Make sure symbols used by other modules are public.
+    
+    These symbols must be explicitly exported, otherwise if compiled with
+    hidden symbols, LoaderSymbol (and dlopen) will fail to find them.
+
+commit 25f4e1729a3447c6288b4acde99f733833661425
+Author: Mark Kettenis <mark.kettenis@xs4all.nl>
+Date:   Thu Jan 31 21:02:48 2008 -0800
+
+    Bug #14246: Fix biuld on OpenBSD.
+
+commit 48eac1a03785c6a795193bb884b2c23dcd5b815b
+Author: Zhenyu Wang <zhenyu.z.wang@intel.com>
+Date:   Thu Jan 31 18:26:46 2008 +0800
+
+    Don't crash if SW cursor
+    
+    In case of device option or hw cursor allocation fails.
+
+commit 103dc34f3afc17cea7e086927e124a30c605a686
+Merge: ae833b8... 5d9e67a...
+Author: Zhenyu Wang <zhenyu.z.wang@intel.com>
+Date:   Fri Jan 25 11:10:42 2008 +0800
+
+    Merge branch 'master' into xf86-video-intel-2.2-branch
+
+commit ae833b82867a14c82ab8054cd0e4e4baaa908bc1
+Merge: 8661ef9... 6bf53eb...
+Author: Zhenyu Wang <zhenyu.z.wang@intel.com>
+Date:   Fri Jan 25 17:17:07 2008 +0800
+
+    Merge branch 'master' into xf86-video-intel-2.2-branch
+
+commit 6bf53eb48f40ad0c8ea9679ee634447410821b4f
+Author: Zhenyu Wang <zhenyu.z.wang@intel.com>
+Date:   Fri Jan 25 16:59:13 2008 +0800
+
+    Set vtSema before EnterVT
+    
+    Which was missing in our ScreenInit and initial EnterVT.
+    This not only causes failure in initial rotation with TTM,
+    as we won't bind in rotate_mem alloc in this case, and hide
+    another bug that we call randr12 function in I830LoadPalete
+    before we call xf86RandR12Init.
+
+commit 5d9e67aec3ce458d22b7febd3819542abb360534
+Author: Erik Andren <erik.andren@gmail.com>
+Date:   Fri Jan 25 11:06:01 2008 +0800
+
+    Clevo M720R has no TV-out
+
+commit 94a18fa1f8141837bdab32e545da7a7aed1cc396
+Author: Julien Cristau <jcristau@debian.org>
+Date:   Thu Jan 24 15:24:40 2008 +0100
+
+    Don't build reg_dumper if we don't have pciaccess 0.10.0
+    
+    The pci_device_map_range() function was added in libpciaccess 0.10.0, and
+    is used by the reg_dumper tool.  Don't try to build it if we have an older


Reply to:
diff --git a/ltmain.sh b/ltmain.sh
index f924d30..5def351 100644
--- a/ltmain.sh
+++ b/ltmain.sh
@@ -2,7 +2,7 @@
 # NOTE: Changing this file will not affect anything until you rerun configure.
 #
 # Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2003, 2004, 2005, 2006,
 # 2007  Free Software Foundation, Inc.
 # Originally by Gordon Matzigkeit <gord@gnu.ai.mit.edu>, 1996
 #
 # This program is free software; you can redistribute it and/or modify
@@ -43,8 +43,8 @@ EXIT_FAILURE=1
 
 PROGRAM=ltmain.sh
 PACKAGE=libtool
-VERSION="1.5.24 Debian 1.5.24-1"
-TIMESTAMP=" (1.1220.2.456 2007/06/24 02:25:32)"
+VERSION="1.5.26 Debian 1.5.26-1"
+TIMESTAMP=" (1.1220.2.493 2008/02/01 16:58:18)"
 
 # Be Bourne compatible (taken from Autoconf:_AS_BOURNE_COMPATIBLE).
 if test -n "${ZSH_VERSION+set}" && (emulate sh) >/dev/null 2>&1; then
@@ -113,15 +113,21 @@ esac
 # These must not be set unconditionally because not all systems understand
 # e.g. LANG=C (notably SCO).
 # We save the old values to restore during execute mode.
-for lt_var in LANG LC_ALL LC_CTYPE LC_COLLATE LC_MESSAGES
+lt_env=
+for lt_var in LANG LANGUAGE LC_ALL LC_CTYPE LC_COLLATE LC_MESSAGES
 do
   eval "if test \"\${$lt_var+set}\" = set; then
 	  save_$lt_var=\$$lt_var
+	  lt_env=\"$lt_var=\$$lt_var \$lt_env\"
 	  $lt_var=C
 	  export $lt_var
 	fi"
 done
 
+if test -n "$lt_env"; then
+  lt_env="env $lt_env"
+fi
+
 # Make sure IFS has a sensible default
 lt_nl='
 '
@@ -485,7 +491,7 @@ do
     echo "\
 $PROGRAM (GNU $PACKAGE) $VERSION$TIMESTAMP
 
-Copyright (C) 2007  Free Software Foundation, Inc.
+Copyright (C) 2008  Free Software Foundation, Inc.
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
     exit $?
@@ -788,6 +794,7 @@ if test -z "$show_help"; then
     *.for) xform=for ;;
     *.java) xform=java ;;
     *.obj) xform=obj ;;
+    *.sx) xform=sx ;;
     esac
 
     libobj=`$echo "X$libobj" | $Xsed -e "s/\.$xform$/.lo/"`
@@ -956,7 +963,7 @@ EOF
       $run $rm "$lobj" "$output_obj"
 
       $show "$command"
-      if $run eval "$command"; then :
+      if $run eval $lt_env "$command"; then :
       else
 	test -n "$output_obj" && $run $rm $removelist
 	exit $EXIT_FAILURE
@@ -1028,7 +1035,7 @@ EOF
       command="$command$suppress_output"
       $run $rm "$obj" "$output_obj"
       $show "$command"
-      if $run eval "$command"; then :
+      if $run eval $lt_env "$command"; then :
       else
 	$run $rm $removelist
 	exit $EXIT_FAILURE
@@ -1161,6 +1168,7 @@ EOF
     thread_safe=no
     vinfo=
     vinfo_number=no
+    single_module="${wl}-single_module"
 
     func_infer_tag $base_compile
 
@@ -1646,6 +1654,11 @@ EOF
 	continue
 	;;
 
+      -multi_module)
+	single_module="${wl}-multi_module"
+	continue
+	;;
+
       -module)
 	module=yes
 	continue
@@ -2152,7 +2165,12 @@ EOF
 	    continue
 	  fi
 	  name=`$echo "X$deplib" | $Xsed -e 's/^-l//'`
-	  for searchdir in $newlib_search_path $lib_search_path $sys_lib_search_path $shlib_search_path; do
+	  if test "$linkmode" = lib; then
+	    searchdirs="$newlib_search_path $lib_search_path $compiler_lib_search_dirs $sys_lib_search_path $shlib_search_path"
+	  else
+	    searchdirs="$newlib_search_path $lib_search_path $sys_lib_search_path $shlib_search_path"
+	  fi
+	  for searchdir in $searchdirs; do
 	    for search_ext in .la $std_shrext .so .a; do
 	      # Search the libtool library
 	      lib="$searchdir/lib${name}${search_ext}"
@@ -2948,12 +2966,18 @@ EOF
 		  # we do not want to link against static libs,
 		  # but need to link against shared
 		  eval deplibrary_names=`${SED} -n -e 's/^library_names=\(.*\)$/\1/p' $deplib`
+		  eval deplibdir=`${SED} -n -e 's/^libdir=\(.*\)$/\1/p' $deplib`
 		  if test -n "$deplibrary_names" ; then
 		    for tmp in $deplibrary_names ; do
 		      depdepl=$tmp
 		    done
-		    if test -f "$path/$depdepl" ; then
+		    if test -f "$deplibdir/$depdepl" ; then
+		      depdepl="$deplibdir/$depdepl"
+	      	    elif test -f "$path/$depdepl" ; then
 		      depdepl="$path/$depdepl"
+		    else
+		      # Can't find it, oh well...
+		      depdepl=
 		    fi
 		    # do not add paths which are already there
 		    case " $newlib_search_path " in
@@ -3101,9 +3125,10 @@ EOF
 
     case $linkmode in
     oldlib)
-      if test -n "$deplibs"; then
-	$echo "$modename: warning: \`-l' and \`-L' are ignored for archives" 1>&2
-      fi
+      case " $deplibs" in
+      *\ -l* | *\ -L*)
+	$echo "$modename: warning: \`-l' and \`-L' are ignored for archives" 1>&2 ;;
+      esac
 
       if test -n "$dlfiles$dlprefiles" || test "$dlself" != no; then
 	$echo "$modename: warning: \`-dlopen' is ignored for archives" 1>&2
@@ -4245,9 +4270,10 @@ EOF
       ;;
 
     obj)
-      if test -n "$deplibs"; then
-	$echo "$modename: warning: \`-l' and \`-L' are ignored for objects" 1>&2
-      fi
+      case " $deplibs" in
+      *\ -l* | *\ -L*)
+	$echo "$modename: warning: \`-l' and \`-L' are ignored for objects" 1>&2 ;;
+      esac
 
       if test -n "$dlfiles$dlprefiles" || test "$dlself" != no; then
 	$echo "$modename: warning: \`-dlopen' is ignored for objects" 1>&2
@@ -6486,7 +6512,7 @@ relink_command=\"$relink_command\""
       fi
 
       # Restore saved environment variables
-      for lt_var in LANG LC_ALL LC_CTYPE LC_COLLATE LC_MESSAGES
+      for lt_var in LANG LANGUAGE LC_ALL LC_CTYPE LC_COLLATE LC_MESSAGES
       do
 	eval "if test \"\${save_$lt_var+set}\" = set; then
 		$lt_var=\$save_$lt_var; export $lt_var
@@ -2,7 +2,7 @@
 #
 # Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2003, 2004, 2005, 2006,
-# 2007  Free Software Foundation, Inc.
+# 2007, 2008  Free Software Foundation, Inc.
 # Originally by Gordon Matzigkeit <gord@gnu.ai.mit.edu>, 1996
 #

commit 0a6a32e4f77b0f63124fb4259e660c8410c2bc61
Author: Julien Cristau <jcristau@debian.org>
Date:   Wed Feb 6 10:24:16 2008 +0100

    Update changelogs
